@@ -29,7 +29,7 @@
 #include <QLineEdit>
 #include <QComboBox>
 #include <QSizePolicy>
-#include <QVector>
+#include <QList>
 #include <QSet>
 #include <QNetworkInterface>
 #include <QHostInfo>
@@ -82,7 +82,7 @@ public:
     }
 
     void fillFrameBuffersCombo() {
-        const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("krfb/framebuffer"), {}, KPluginMetaData::AllowEmptyMetaData);
+        const QList<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("krfb/framebuffer"), {}, KPluginMetaData::AllowEmptyMetaData);
         for (const KPluginMetaData &metadata : plugins) {
             cb_preferredFrameBufferPlugin->addItem(metadata.pluginId());
         }
@@ -145,8 +145,8 @@ MainWindow::MainWindow(QWidget *parent)
     m_ui.passwordDisplayLabel->setText(
             InvitationsRfbServer::instance->desktopPassword());
 
-    KStandardAction::quit(QCoreApplication::instance(), SLOT(quit()), actionCollection());
-    KStandardAction::preferences(this, SLOT(showConfiguration()), actionCollection());
+    KStandardAction::quit(QCoreApplication::instance(), &QCoreApplication::quit, actionCollection());
+    KStandardAction::preferences(this, &MainWindow::showConfiguration, actionCollection());
 
     setupGUI();
 
